from __future__ import annotations

from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXVerticalFrame import FXVerticalFrame


class AFXVerticalAligner(FXVerticalFrame):
    """This class is used to automatically vertically align its children "container" widgets (e.g. AFXTextField
    or AFXComboBox).

    The width of the first widget in the container of each child of the vertical aligner is set to the width
    of the widest first widget of all the vertical aligner's children.
    """

    def __init__(
        self,
        p: FXComposite,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = 0,
        pr: int = 0,
        pt: int = 0,
        pb: int = 0,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        opts : int
            Options and hints.
        x : int
            X coordinate of the origin.
        y : int
            Y coordinate of the origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding (margin).
        pr : int
            Right padding (margin).
        pt : int
            Top padding (margin).
        pb : int
            Bottom padding (margin).
        hs : int
            Horizontal spacing.
        vs : int
            Vertical spacing.
        """

    def create(self):
        """Creates the aligner.

        Reimplemented from FXComposite.
        """

    def getDefaultHeight(self):
        """Returns the default height.

        Reimplemented from FXVerticalFrame.
        """

    def getDefaultWidth(self):
        """Returns the default width.

        Reimplemented from FXVerticalFrame. By clicking on Send, you accept that Dassault Systèmes will process your personal data and may contact you for further information. [Privacy Policy](https://www.3ds.com/privacy-policy). Total Results: Results per page This page cannot be found. The page might not exist or is temporarily unavailable. Try again or try searching for the topic. Provide Feedback on This Topic Use this form to provide feedback on this help topic. To get product support or to provide product feedback, go to [Frequently Asked Questions](https://3ds.one/PO). For support for online purchased solutions, go to [Online Purchase Support](https://3ds.one/Q8). * Required Subject: Feedback on User Assistance * I acknowledge I have read and I hereby accept the [privacy policy](https://www.3ds.com/privacy-policy) under which my personal data will be used by Dassault Systèmes. 2016 - Go to 2016 home page 2017 - Go to the same topic in 2017 2018 - Go to the same topic in 2018 2019 - Go to the same topic in 2019 2020 - Go to the same topic in 2020 2021 - Go to the same topic in 2021 2022 - Go to the same topic in 2022 2023 - Go to the same topic in 2023 2016 - Go to 2016 home page 2017 - Go to the same topic in 2017 2018 - Go to the same topic in 2018 2019 - Go to the same topic in 2019 2020 - Go to the same topic in 2020 2021 - Go to the same topic in 2021 2022 - Go to the same topic in 2022 2023 - Go to the same topic in 2023
        """



from __future__ import annotations

from typing_extensions import Self

from .constants import DEFAULT_SPACING
from .FXComposite import FXComposite
from .FXObject import FXObject
from .FXPacker import FXPacker


class AFXOptionTreeItem(FXPacker):
    """This class is a tree widget with check buttons."""

    #: Toggles display of frame with children.
    ID_TOGGLEEXPAND: int = hash("ID_TOGGLEEXPAND")

    #: Represents checked state of this object.
    ID_CHECKSTATE: int = hash("ID_CHECKSTATE")

    #: Container for the subtree.
    ID_SUBTREE: int = hash("ID_SUBTREE")

    #: Expands frame with children.
    ID_EXPAND: int = hash("ID_EXPAND")

    #: Collapses frame with children.
    ID_COLLAPSE: int = hash("ID_COLLAPSE")

    def __init__(
        self,
        p: FXComposite,
        label: str,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_SPACING,
        pr: int = DEFAULT_SPACING,
        pt: int = DEFAULT_SPACING,
        pb: int = DEFAULT_SPACING,
        hs: int = DEFAULT_SPACING,
        vs: int = DEFAULT_SPACING,
    ):
        """Constructor creating a top-level (root) tree item.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        label : str
            Label text.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        opts : int
            Options and hints.
        x : int
            X coordinate of origin.
        y : int
            Y coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding.
        pr : int
            Right padding.
        pt : int
            Top padding.
        pb : int
            Bottom padding.
        hs : int
            Horizontal spacing.
        vs : int
            Vertical spacing.
        """

    def addItemAfter(self, label: str, tgt: FXObject | None = None, sel: int = 0):
        """Creates a new tree item as a sibling after (below) the tree item.

        Parameters
        ----------
        label : str
            Item label.
        tgt : FXObject | None
            Item target.
        sel : int
            Item selector.
        """

    def addItemBefore(self, label: str, tgt: FXObject | None = None, sel: int = 0):
        """Creates a new tree item as a sibling before (above) the tree item.

        Parameters
        ----------
        label : str
            Item label.
        tgt : FXObject | None
            Item target.
        sel : int
            Item selector.
        """

    def addItemFirst(self, label: str, tgt: FXObject | None = None, sel: int = 0):
        """Creates a new tree item as the first child of the tree item.

        Parameters
        ----------
        label : str
            Item label.
        tgt : FXObject | None
            Item target.
        sel : int
            Item selector.
        """

    def addItemLast(self, label: str, tgt: FXObject | None = None, sel: int = 0):
        """Creates a new tree item as the last child of the tree item.

        Parameters
        ----------
        label : str
            Item label.
        tgt : FXObject | None
            Item target.
        sel : int
            Item selector.
        """

    def childAtIndex(self, index: int):
        """Returns the child tree at the given index.

        Parameters
        ----------
        index : int
            Index.
        """

    def collapse(self):
        """Collapses (hides) the children."""

    def computeDefaultArrowSize(self):
        """Computes default size of the arrow button."""

    def containsChild(self, tree: Self):
        """Checks whether the given tree is a child of this object.

        Parameters
        ----------
        tree : Self
            Item.
        """

    def create(self):
        """Creates the tree item.

        Reimplemented from FXComposite.
        """

    def disable(self):
        """Disables the tree item.

        Reimplemented from FXWindow.
        """

    def enable(self):
        """Enables the tree item.

        Reimplemented from FXWindow.
        """

    def expand(self):
        """Expands (shows) the children."""

    def getArrowSize(self):
        """Returns the size of the arrow button."""

    def getCheck(self):
        """Returns the check state of the tree item."""

    def getDefaultWidth(self):
        """Returns the default width of the tree item.

        Reimplemented from FXPacker.
        """

    def getFirst(self):
        """Returns the first child tree.

        Reimplemented from FXWindow.
        """

    def getLast(self):
        """Returns the last child tree.

        Reimplemented from FXWindow.
        """

    def getNext(self):
        """Returns the next sibling tree.

        Reimplemented from FXWindow.
        """

    def getParent(self):
        """Returns the parent tree widget, or NULL if the tree item is the root.

        Reimplemented from FXWindow.
        """

    def getPrev(self):
        """Returns the previous sibling tree.

        Reimplemented from FXWindow.
        """

    def getText(self):
        """Returns the label text shown in the tree item's check button."""

    def hasVisibleChildren(self):
        """Checks whether the tree item has any visible children."""

    def hide(self):
        """Hides the tree item.

        Reimplemented from FXWindow.
        """

    def indexOfChild(self, tree: Self):
        """Returns the index of an immediate child tree, or -1 if not found.

        Parameters
        ----------
        tree : Self
            Item.
        """

    def isChildOf(self, tree: Self):
        """Checks whether this object is contained in the given tree.

        Parameters
        ----------
        tree : Self
            Item.
        """

    def isExpanded(self):
        """Checks whether the tree item shows its children."""

    def numChildren(self):
        """Returns the number of child trees.

        Reimplemented from FXWindow.
        """

    def setArrowSize(self, size: int):
        """Sets the size of the arrow button for this object and all its children.

        Parameters
        ----------
        size : int
            Size.
        """

    def setCheck(self, check: int = True):
        """Sets the check state of the tree item and its children.

        Parameters
        ----------
        check : int
            Check state.
        """

    def setText(self, txt: str):
        """Sets the label text shown in the tree item's check button.

        Parameters
        ----------
        txt : str
            Label text.
        """

    def show(self):
        """Shows the tree item.

        Reimplemented from FXWindow.
        """

    def updateCheck(self, notify: bool):
        """Updates the check state of the tree item and its ancestors.

        Parameters
        ----------
        notify : bool
            Notification flag.
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from .MdbDataInstance import MdbDataInstance
from .MdbDataStep import MdbDataStep


@abaqus_class_doc
class MdbData:
    """The MdbData object has no constructor. Abaqus creates an MdbData object when a cae file is opened or a
    new model is created. There is one MdbData for each model in session. MdbData is updated when it is
    displayed in a viewport.

    .. note::
        This object can be accessed by::

            import visualization
            session.mdbData[name]
    """

    #: A tuple of (String, Float) tuples specifying the stepName and the stepPeriod.
    stepPeriods: float | None = None

    #: A repository of MdbDataStep objects specifying the list of steps. The repository is
    #: read-only.
    steps: dict[str, MdbDataStep] = {}

    #: A repository of MdbDataInstance objects specifying the list of instances. The repository
    #: is read-only.
    instances: dict[str, MdbDataInstance] = {}



from __future__ import annotations

from .AFXIntTarget import AFXIntTarget
from .FXObject import FXObject


class AFXTransition(FXObject):
    """This class is designed for the finite state transition that the GUI (mostly the dialog boxes) can define
    to perform actions according to state changes.

    The first three arguments of the constructors (keyword, op, and refValue) define an expression
    (keyword.getValue() op refValue). The current value of the keyword is compared with the reference value.
    When the expression evaluates to True, a message with the given selector will be sent to the specified
    message target.
    """

    class Operator:
        ...

    #: Equal to.
    EQ: int = hash("EQ")

    #: Not equal to.
    NE: int = hash("NE")

    #: Less than.
    LT: int = hash("LT")

    #: Less than or equal to.
    LE: int = hash("LE")

    #: Greater than.
    GT: int = hash("GT")

    #: Greater than or equal to.
    GE: int = hash("GE")

    def __init__(
        self, intTarget: AFXIntTarget, op: Operator, refValue: int, tgt: FXObject, sel: int, ptr: str = "None"
    ):
        """Constructor.

        Parameters
        ----------
        intTarget : AFXIntTarget
            Target.
        op : Operator
            Operator type.
        refValue : int
            Reference value.
        tgt : FXObject
            Message target.
        sel : int
            Message selector.
        ptr : str
            Message data.
        """

    def process(self, sender: FXObject):
        """Returns True and sends a message if the expression defined by the constructor arguments evaluates to
        True; returns False without performing any actions if otherwise.

        Parameters
        ----------
        sender : FXObject
            Message sender.
        """



from __future__ import annotations

from typing import Any

from typing_extensions import Self

from .FXMetaClass import FXMetaClass
from .FXSelector import FXSelector


class FXObject:
    """Base of all FOX object."""

    def getClassName(self):
        """Get class name of some object."""

    def isMemberOf(self, metaclass: FXMetaClass):
        """Check if object is member of metaclass.

        Parameters
        ----------
        metaclass : FXMetaClass
        """

    def onDefault(self):
        """Called for unhandled messages.

        Reimplemented in FXDelegator, FXGLViewer, FXMDIChild, and FXMDIClient.
        """

    def handle(self, sender: Self, sel: FXSelector, ptr: Any):
        """Handles messages sent to this class.

        Parameters
        ----------
        sender : Self
            The sender of the message.
        sel : FXSelector
            The selector of the message.
        ptr : Any
            Associated data.
        """



from __future__ import annotations

from .AFXGuiObjectManager import AFXGuiObjectManager
from .FXComposite import FXComposite
from .FXMatrix import FXMatrix


class AFXToolboxGroup(FXMatrix):
    """This class creates a container to be used for groups in the toolbox.

    It will use utility methods so the group is correctly managed for modules and toolsets.
    """

    def __init__(self, owner: AFXGuiObjectManager, parent: FXComposite | None = None):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Creator of the toolbox group.
        parent : FXComposite | None
            Parent widget.
        """

    def getOwner(self):
        """Returns the owner of the toolbox group.

        Reimplemented from FXWindow.
        """



from __future__ import annotations

from .AFXObjectKeyword import AFXObjectKeyword
from .AFXProcedure import AFXProcedure
from .AFXStep import AFXStep
from .AFXTupleKeyword import AFXTupleKeyword


class AFXPickStep(AFXStep):
    """This class is used to provide pick steps in GUI procedures."""

    #: Allow only one entity to be picked.
    ONE: int = hash("ONE")

    #: Allow one or more entities to be picked.
    MANY: int = hash("MANY")

    #: Allow only straight entities to be picked.
    STRAIGHT: int = hash("STRAIGHT")

    #: Allow only wire entities to be picked.
    WIRE: int = hash("WIRE")

    #: Allow only planar entities to be picked.
    PLANAR: int = hash("PLANAR")

    #: Allow only conical entities to be picked.
    CONICAL: int = hash("CONICAL")

    #: Allow only shell entities to be picked.
    SHELL: int = hash("SHELL")

    #: Allow only orphan mesh entities to be picked.
    ORPHAN_MESH: int = hash("ORPHAN_MESH")

    #: Allow only solid entities to be picked.
    SOLID: int = hash("SOLID")

    #: Allow only geometry entities to be picked.
    GEOMETRY: int = hash("GEOMETRY")

    #: Allow only point entities to be picked.
    POINT: int = hash("POINT")

    #: Allow only background entities to be picked while sketching.
    BACKGROUND: int = hash("BACKGROUND")

    #: Allow only sketch entities to be picked.
    FOREGROUND: int = hash("FOREGROUND")

    #: Allow only vertical geometric sketch entities to be picked.
    VERTICAL: int = hash("VERTICAL")

    #: Allow only horizontal geometric sketch entities to be picked.
    HORIZONTAL: int = hash("HORIZONTAL")

    #: Allow only construction sketch entities to be picked.
    CONSTRUCTION: int = hash("CONSTRUCTION")

    #: Allow only non-construction geometric sketch entities to be picked.
    NO_CONSTRUCTION: int = hash("NO_CONSTRUCTION")

    #: Allow only spot sketch entities to be picked.
    SPOT: int = hash("SPOT")

    #: Allow only circular sketch entities to be picked.
    CIRCULAR: int = hash("CIRCULAR")

    #: Allow only interior entities to be picked.
    INTERIOR: int = hash("INTERIOR")

    #: Allow only exterior entities to be picked.
    EXTERIOR: int = hash("EXTERIOR")

    #: Allow vertices to be picked.
    VERTICES: int = hash("VERTICES")

    #: Allow edges to be picked.
    EDGES: int = hash("EDGES")

    #: Allow faces to be picked.
    FACES: int = hash("FACES")

    #: Allow cells to be picked.
    CELLS: int = hash("CELLS")

    #: Allow stringers to be picked.
    STRINGERS: int = hash("STRINGERS")

    #: Allow skins to be picked.
    SKINS: int = hash("SKINS")

    #: Allow element edges to be picked.
    ELEMENT_EDGES: int = hash("ELEMENT_EDGES")

    #: Allow element faces to be picked.
    ELEMENT_FACES: int = hash("ELEMENT_FACES")

    #: Allow nodes to be picked.
    NODES: int = hash("NODES")

    #: Allow elements to be picked.
    ELEMENTS: int = hash("ELEMENTS")

    #: Allow part instances in the model database to be picked.
    INSTANCES: int = hash("INSTANCES")

    #: Allow picking only objects of the highest dimension (1D, 2D, 3D).
    MAX_DIMENSION: int = hash("MAX_DIMENSION")

    #: Allow reference points to be picked.
    REFERENCE_POINTS: int = hash("REFERENCE_POINTS")

    #: Allow interesting points to be picked.
    INTERESTING_POINTS: int = hash("INTERESTING_POINTS")

    #: Allow datum points to be picked.
    DATUM_POINTS: int = hash("DATUM_POINTS")

    #: Allow datum axes to be picked.
    DATUM_AXES: int = hash("DATUM_AXES")

    #: Allow datsum planes be picked.
    DATUM_PLANES: int = hash("DATUM_PLANES")

    #: Allow datum CSYS's to be picked.
    DATUM_CSYS: int = hash("DATUM_CSYS")

    #: Allow edges to be removed from face selections.
    REMOVABLE_EDGES: int = hash("REMOVABLE_EDGES")

    #: Allow features to be picked.
    FEATURES: int = hash("FEATURES")

    #: Allow sketch vertices to be picked.
    SKETCH_VERTICES: int = hash("SKETCH_VERTICES")

    #: Allow sketch geometries to be picked.
    SKETCH_GEOMETRIES: int = hash("SKETCH_GEOMETRIES")

    #: Allow sketch dimensions to be picked.
    SKETCH_DIMENSIONS: int = hash("SKETCH_DIMENSIONS")

    #: Allow sketch constraints to be picked.
    SKETCH_CONSTRAINTS: int = hash("SKETCH_CONSTRAINTS")

    #: Allow sketch coordinates to be picked must add keyin.
    SKETCH_COORDINATES: int = hash("SKETCH_COORDINATES")

    #: Allow elements on skins to be picked.
    SKIN_ELEMENTS: int = hash("SKIN_ELEMENTS")

    #: Allow elements on stringers to be picked.
    STRINGER_ELEMENTS: int = hash("STRINGER_ELEMENTS")

    #: Allow all types of points to be picked.
    POINTS: int = hash("POINTS")

    #: Allow all types of lines to be picked.
    LINES: int = hash("LINES")

    #: Allow all types of planes to be picked.
    PLANES: int = hash("PLANES")

    #: Allow picking of XY coordinates from an XY plot.
    XY_POINT: int = hash("XY_POINT")

    #: Allow picking of XY coordinates from an XY plot, with the option to type in XY values.
    XY_COORDINATE: int = hash("XY_COORDINATE")

    #: Specify pick as a comma separated tuple of single items.
    TUPLE: int = hash("TUPLE")

    #: Specify pick as a plus separated sequence items.
    ARRAY: int = hash("ARRAY")

    def __init__(
        self,
        owner: AFXProcedure,
        keyword: AFXObjectKeyword,
        prompt: str,
        entitiesToPick: int,
        numberToPick=ONE,
        highlightLevel: int = 1,
        sequenceStyle=ARRAY,
    ):
        """Constructor.

        Parameters
        ----------
        owner : AFXProcedure
            Procedure creating the step.
        keyword : AFXObjectKeyword
            Object kwd containing pick variable. Part of AFXGuiCommand.
        prompt : str
            Step's prompt displayed in prompt area.
        entitiesToPick : int
            Type of entities to pick.
        numberToPick : pickAmountEnum
            How many entities to pick.
        highlightLevel : int
            Highlight level.
        sequenceStyle : sequenceStyleEnum
            Sequence style of picked variables in the command.
        """

    def addElementSetSelection(self, name: str):
        """Adds an element set to the step's selections.

        Parameters
        ----------
        name : str
            Name of set.
        """

    def addGeometrySetSelection(self, name: str):
        """Adds a geometry set to the step's selections.

        Parameters
        ----------
        name : str
            Name of set.
        """

    def addNodeSetSelection(self, name: str):
        """Adds a node set to the step's selections.

        Parameters
        ----------
        name : str
            Name of set.
        """

    def addPointKeyIn(self, keyword: AFXTupleKeyword):
        """Creates a textfield on the prompt line as an alternative method of specifying a point.

        Parameters
        ----------
        keyword : AFXTupleKeyword
            Keyword
        """

    def addSurfaceSelection(self, name: str):
        """Adds a surface to the step's selections.

        Parameters
        ----------
        name : str
            Name of surface.
        """

    def allowRepeatedSelections(self, value: bool = True):
        """Allows the picking of prior selections (from prior pick steps of the procedure).

        Parameters
        ----------
        value : bool
            If True, allow repeated selections between steps.
        """

    def onCancel(self):
        """Called when the step is cancelled.

        Reimplemented from AFXStep. Reimplemented in AFXOrderedPickStep.
        """

    def onExecute(self):
        """Called to execute the steps returned by getFirstStep and getNextStep.

        Reimplemented from AFXStep. Reimplemented in AFXOrderedPickStep.
        """

    def onResume(self):
        """Called when the step is resumed.

        Reimplemented from AFXStep.
        """

    def onSuspend(self):
        """Called when the step is suspended.

        Reimplemented from AFXStep.
        """

    def reset(self):
        """Allows a step to reset any of its data (if needed) when looping.

        Reimplemented from AFXStep. Reimplemented in AFXOrderedPickStep.
        """

    def setEdgeRefinements(self, refinement: int):
        """Sets the refinements to be used when picking edges.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setElementEdgeRefinements(self, refinement: int):
        """Sets the refinements to be used when picking element edges.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setElementFaceRefinements(self, refinement: int):
        """Sets the refinements to be used when picking element faces.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setElementRefinements(self, refinement: int):
        """Sets the refinements to be used when picking elements.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setFaceRefinements(self, refinement: int):
        """Sets the refinements to be used when picking faces.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setInstanceRefinements(self, refinement: int):
        """Sets the refinements to be used when picking instances.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setNodeRefinements(self, refinement: int):
        """Sets the refinements to be used when picking nodes.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setSketchRefinements(self, refinement: int):
        """Sets the refinements to be used when picking sketches.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """

    def setXyRefinements(self, refinement: int):
        """Sets the refinements to be used when picking xy objects.

        Parameters
        ----------
        refinement : int
            Refinement flag.
        """



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import ON, Boolean


@abaqus_class_doc
class StopConditionDisplayOptions:
    """The StopConditionDisplayOptions object stores settings that specify how assemblies are to be displayed in
    a particular viewport when session.viewports[name].assemblyDisplay.stopConditions=ON The
    StopConditionDisplayOptions object has no constructor. When you create a new viewport, the settings are
    copied from the current viewport.

    .. note::
        This object can be accessed by::

            session.viewports[name].assemblyDisplay.stopConditionOptions
            session.viewports[name].layers[name].assemblyDisplay.stopConditionOptions
    """

    @abaqus_method_doc
    def setValues(self, localStopCondition: Boolean = ON):
        """This method modifies the StopConditionDisplayOptions object.

        Parameters
        ----------
        localStopCondition
            A Boolean specifying whether local stop condition symbols are shown. The default value
            is ON.

        Raises
        ------
        RangeError
        """
        ...



from __future__ import annotations

from typing import Sequence

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..Region.Region import Region
from .Crack import Crack
from .Fastener import Fastener
from .Inertia import Inertia
from .SpringDashpot import SpringDashpot


@abaqus_class_doc
class EngineeringFeatureBase:
    """The EngineeringFeature object is a container for various specific engineering feature repositories. The
    EngineeringFeature object has no explicit constructor or methods.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].engineeringFeatures
            import assembly
            mdb.models[name].rootAssembly.engineeringFeatures
    """

    #: A repository of Inertia objects.
    inertias: dict[str, Inertia] = {}

    #: A repository of Crack objects.
    cracks: dict[str, Crack] = {}

    #: A repository of Fastener objects.
    fasteners: dict[str, Fastener] = {}

    #: A repository of SpringDashpot objects.
    springDashpots: dict[str, SpringDashpot] = {}

    @abaqus_method_doc
    def assignSeam(self, regions: Sequence[Region]):
        """This method creates a seam crack along an edge or a face.

        Parameters
        ----------
        regions
            A sequence of Region objects specifying the domain of the seam crack. The Region objects
            must be faces or edges.
        """
        ...

    @abaqus_method_doc
    def deleteSeam(self, regions: Sequence[Region]):
        """This method deletes a seam crack.

        Parameters
        ----------
        regions
            A sequence of Region objects specifying the domain of the seam crack. The Region objects
            must be faces or edges.
        """
        ...



from __future__ import annotations

from .FXApp import FXApp
from .FXComposite import FXComposite
from .FXVisual import FXVisual


class FXRootWindow(FXComposite):
    """Root window."""

    def __init__(self, a: FXApp, vis: FXVisual):
        """Construct root window.

        Parameters
        ----------
        a : FXApp

        vis : FXVisual
        """

    def create(self):
        """Root window need not be created.

        Reimplemented from FXComposite.
        """

    def destroy(self):
        """Root window can not be destroyed.

        Reimplemented from FXComposite.
        """

    def detach(self):
        """Root window may not be detached.

        Reimplemented from FXComposite.
        """

    def getDefaultHeight(self):
        """Return height of the root window.

        Reimplemented from FXComposite.
        """

    def getDefaultWidth(self):
        """Return width of the root window.

        Reimplemented from FXComposite.
        """

    def move(self, x: int, y: int):
        """Root window can not be moved. Reimplemented from FXWindow.

        Parameters
        ----------
        x : int

        y : int
        """

    def position(self, x: int, y: int, w: int, h: int):
        """Root window can not be positioned. Reimplemented from FXWindow.

        Parameters
        ----------
        x : int

        y : int

        w : int

        h : int
        """

    def recalc(self):
        """No op.

        Reimplemented from FXWindow.
        """

    def resize(self, w: int, h: int):
        """Root window can not be resized. Reimplemented from FXWindow.

        Parameters
        ----------
        w : int

        h : int
        """



from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .Datum import Datum
from .DatumAxis import DatumAxis
from .DatumPoint import DatumPoint


@abaqus_class_doc
class DatumCsys(Datum):
    """The DatumCsys object has no direct constructor; it is created when a Feature object is created. For
    example, the DatumCsysByOffset method creates a Feature object that creates a DatumCsys object. The
    DatumCsys object is derived from the Datum object.

    .. note::
        This object can be accessed by::

            import part
            mdb.models[name].parts[name].datums[i]
            import assembly
            mdb.models[name].rootAssembly.allInstances[name].datums[i]
            mdb.models[name].rootAssembly.connectorOrientations[i].localCsys1
            mdb.models[name].rootAssembly.connectorOrientations[i].localCsys2
            mdb.models[name].rootAssembly.datums[i]
            mdb.models[name].rootAssembly.instances[name].datums[i]
            import odbAccess
            session.odbs[name].rootAssembly.connectorOrientations[i].localCsys1
            session.odbs[name].rootAssembly.connectorOrientations[i].localCsys2
    """

    #: A SymbolicConstant specifying the type of the coordinate system. Possible values are
    #: CARTESIAN, CYLINDRICAL, and SPHERICAL.
    coordSysType: SymbolicConstant

    #: A DatumPoint object specifying the origin of the coordinate system.
    origin: DatumPoint = DatumPoint()

    #: A DatumAxis object specifying the 1-direction of the coordinate system.
    axis1: DatumAxis = DatumAxis()

    #: A DatumAxis object specifying the 2-direction of the coordinate system.
    axis2: DatumAxis = DatumAxis()

    #: A DatumAxis object specifying the 3-direction of the coordinate system.
    axis3: DatumAxis = DatumAxis()



from __future__ import annotations

from typing import List

from .SubstructureGenerateFrequency import SubstructureGenerateFrequency

SubstructureGenerateFrequencyArray = List[SubstructureGenerateFrequency]



from __future__ import annotations

from .AFXTarget import AFXTarget


class AFXStringTarget(AFXTarget):
    """This class is designed for string targets."""

    def __init__(self, initialValue: str = "''"):
        """Constructor.

        Parameters
        ----------
        initialValue : str
            Initial value.
        """

    def getTypeName(self):
        """Returns the name of the target type ("String").

        Implements AFXTarget.
        """

    def getValue(self):
        """Returns the target's current value."""

    def setValue(self, newValue: str):
        """Sets the target's current value.

        Parameters
        ----------
        newValue : str
            New value.
        """



from __future__ import annotations

import os
import re
import sys

from abaqus import Mdb, backwardCompatibility, getInput, mdb
from abaqus.Session.Session import Session
from abaqus.UtilityAndView import BackwardCompatibility, SymbolicConstant
from abaqus.UtilityAndView.AbaqusBoolean import AbaqusBoolean
from abaqus.UtilityAndView.abaqusConstants import (
    CFD,
    EMAG,
    FALSE,
    NOT_SET,
    OFF,
    ON,
    SCATTERED,
    STANDARD_EXPLICIT,
    STEP_END,
    TOTAL,
    TRUE,
    AbaqusBooleanType,
    Boolean,
    BooleanType,
    SymbolicConstantType,
)
from abaqus.UtilityAndView.Repository import Repository

NoneType = type(None)


MdbType = Mdb
BackwardCompatibilityType = BackwardCompatibility
SessionType = Session
RepositoryType = Repository


# Inspected from Abaqus/CAE 2021 Command Line Interface
__all__ = [
    "AbaqusBoolean",
    "AbaqusBooleanType",
    # 'AbaqusException',
    # 'AbaqusShutdown',
    "BackwardCompatibilityType",
    "Boolean",
    "BooleanType",
    "CFD",
    "EMAG",
    "FALSE",
    "Mdb",
    "MdbType",
    "NOT_SET",
    "NoneType",
    "OFF",
    "ON",
    "RepositoryType",
    "SCATTERED",
    "STANDARD_EXPLICIT",
    "STEP_END",
    "SessionType",
    "SymbolicConstant",
    "SymbolicConstantType",
    "TOTAL",
    "TRUE",
    # '__builtins__',
    # '__doc__',
    # '__name__',
    # '__package__',
    # '_fireQuery',
    # '_getCurrentExecFileCmd',
    # '_getDebug',
    # '_getMdbSchema',
    # '_getMdbUpToDateStatus',
    # '_getShowDisplaysState',
    # '_getShowLandmarksState',
    # '_getShowVerbosesState',
    # '_getShowWarningsState',
    # '_getWarningReply',
    # '_journalMethodCallInternal',
    # '_listDebug',
    # '_pprint',
    # '_printToCli',
    # '_replayCapture',
    # '_setCallVerifyMdb',
    # '_setDebug',
    # '_setImportModuleHook',
    # '_setMessagesState',
    # '_shutdowm',
    # '_upgradeTableMdb',
    # 'addCmdToCommandHistory',
    # 'applicationName',
    "backwardCompatibility",
    # 'compress',
    # 'copyrightYear',
    "getInput",
    # 'getInputs',
    # 'getMdbVersionNumbers',
    # 'getReplayFileName',
    # 'isMdbChanged',
    # 'isMdbStudentEdition',
    # 'isStudentEdition',
    # 'journalMethodDecrement',
    # 'journalMethodIncrement',
    # 'landmark',
    # 'majorVersion',
    "mdb",
    # 'mdbVersion',
    # 'milestone',
    # 'minorVersion',
    # 'odbVersion',
    # 'openMdb',
    "os",
    "re",
    # 'showStopButtonInGui',
    "sys",
    # 'uncompress',
    # 'updateVersion',
    # 'upgradeMdb',
    # 'version'
]



from __future__ import annotations

from typing import Sequence

from abqpy.decorators import abaqus_class_doc


@abaqus_class_doc
class CurrentProbeValues:
    """The CurrentProbeValues object has no constructor. The CurrentProbeValues object is created when you
    import the Visualization module.

    .. note::
        This object can be accessed by::

            import visualization
            session.currentProbeValues
    """

    #: A tuple of Floats specifying the values obtained while probing. These values are updated
    #: constantly as the user moves the mouse over the object being probed.
    values: Sequence[float] | None = None



from __future__ import annotations

from .AFXDialog import AFXDialog
from .AFXGuiMode import AFXGuiMode
from .AFXGuiObjectManager import AFXGuiObjectManager
from .AFXStep import AFXStep
from .FXObject import FXObject


class AFXProcedure(AFXGuiMode):
    """This class provides the basis for writing procedures."""

    #: ID for handling bailout.
    ID_HANDLE_2BTN_BAILOUT: int = hash("ID_HANDLE_2BTN_BAILOUT")

    #: ID for the backup button.
    ID_BACKUP: int = hash("ID_BACKUP")

    #: Pick entities inside the drag shape only.
    INSIDE: int = hash("INSIDE")

    #: Pick entities inside and crossing the drag shape.
    INSIDE_CROSSING: int = hash("INSIDE_CROSSING")

    #: Pick entities crossing the drag shape only.
    CROSSING: int = hash("CROSSING")

    #: Pick entities outside and crossing the drag shape.
    OUTSIDE_CROSSING: int = hash("OUTSIDE_CROSSING")

    #: Pick entities outside the drag shape only.
    OUTSIDE: int = hash("OUTSIDE")

    #: Use rectangular drag shape.
    RECTANGLE: int = hash("RECTANGLE")

    #: Use circular drag shape.
    CIRCLE: int = hash("CIRCLE")

    #: Use polygonal drag shape.
    POLYGON: int = hash("POLYGON")

    #: Only pick the entity closest to the screen.
    CLOSEST: int = hash("CLOSEST")

    #: Pick entities at any depth.
    INFINITE: int = hash("INFINITE")

    #: Pick only interior entities.
    INTERIOR: int = hash("INTERIOR")

    #: Pick only exterior entities.
    EXTERIOR: int = hash("EXTERIOR")

    #: Pick all entities.
    ALL: int = hash("ALL")

    #: Cancel the currently running procedure (default).
    NORMAL: int = hash("NORMAL")

    #: Suspend the currently running procedure.
    SUBPROCEDURE: int = hash("SUBPROCEDURE")

    def __init__(self, owner: AFXGuiObjectManager, type=NORMAL):
        """Constructor.

        Parameters
        ----------
        owner : AFXGuiObjectManager
            Owner (a module or a toolset) of the procedure.
        type : typeEnum
        """

    def activate(self):
        """Activates the mode.

        Reimplemented from AFXGuiMode.
        """

    def cancel(self, tgt: FXObject | None = None, msg: int = 0):
        """Tries to cancel the procedure depending on checkCancel results.

        Parameters
        ----------
        tgt : FXObject | None
            Completion message target.
        msg : int
            Completion message ID.
        """

    def checkBackup(self):
        """Returns 1 if ok to backup else returns 0."""

    def checkCancel(self):
        """Returns BAILOUT_NOTOK, BAILOUT_OK, BAILOUT_WIP (writes to the message area), or BAILOUT_SAVE (use the
        3 button save dialog box)."""

    def commit(self):
        """Commits the procedure when the current dialog box calls either done or value changed.

        Implements AFXGuiMode.
        """

    def continueMode(self):
        """Used to get the next step in the mode.

        Implements AFXGuiMode.
        """

    def deactivate(self):
        """Deactivates the mode.

        Reimplemented from AFXGuiMode.
        """

    def getCurrentStep(self):
        """Returns the current step."""

    def getFirstStep(self):
        """Returns the first step to be executed in the procedure."""

    def getLoopStep(self):
        """Returns the step to which the procedure should loop back after processing its commands; if zero is
        returned (the default behavior) the procedure will not loop."""

    def getNextStep(self, previousStep: AFXStep):
        """Returns the next step to be executed; if zero is returned the procedure will process its commands.

        Parameters
        ----------
        previousStep : AFXStep
            Previous step.
        """

    def getNumSteps(self):
        """Returns the number of steps in the step stack."""

    def handleException(self, exc):
        """This method is called if an error occurs while issuing commands. It can be reimplemented in derived
        classes to perform special error handling.

        Parameters
        ----------
        exc : nex_Exception
            Exception.
        """

    def onBackup(self):
        """Called when a procedure backs up a step."""

    def onCancel(self):
        """Called when a procedure cancels."""

    def onCmdBackup(self, sender: FXObject, sel: int, ptr: str):
        """Message handler for handling backup button activation.

        Parameters
        ----------
        sender : FXObject
            Sender.
        sel : int
            Selector.
        ptr : str
            Data.
        """

    def onCmdHandle2BtnBailout(self, sender: FXObject, sel: int, ptr: str):
        """Message handler for handling the user 2 button bailout choice.

        Parameters
        ----------
        sender : FXObject
            Sender.
        sel : int
            Selector.
        ptr : str
            Data.
        """

    def onCmdHandleBailout(self, sender: FXObject, sel: int, ptr: str):
        """Message handler for handling the user 3 button bailout choice.

        Parameters
        ----------
        sender : FXObject
            Sender.
        sel : int
            Selector.
        ptr : str
            Data.
        """

    def onResume(self):
        """Called when a procedure resumes."""

    def onSuspend(self):
        """Called when a procedure suspends."""

    def onValueChanged(self):
        """Called when a procedure's step changes in value."""

    def setCurrentDb(self, db: AFXDialog):
        """Sets the current dialog box of the mode. Procedures will have this set by AFXDialogStep.

        Parameters
        ----------
        db : AFXDialog
            Dialog box.
        """

    def setSelectionOptions(
        self,
        pickDepth=CLOSEST,
        pickScope=ALL,
        dragShape=RECTANGLE,
        dragScope=INSIDE_CROSSING,
        isoLines: bool = True,
    ):
        """Sets the selection options to be used for picking.

        Parameters
        ----------
        pickDepth : pickDepthEnum
            Depth into the screen of picking.
        pickScope : pickScopeEnum
            Entity type.
        dragShape : dragShapeEnum
            Drag-window shape.
        dragScope : dragScopeEnum
            Drag-window scope.
        isoLines : bool
            If True, show isolines on surfaces.
        """

    def verifyCurrentKeywordValues(self):
        """Checks whether keywords of active commands for the current dialog box contain valid data and, if not,
        posts a dialog box with an error message.

        Reimplemented from AFXGuiMode.
        """



from __future__ import annotations

from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXListItem import FXListItem
from .FXObject import FXObject
from .FXScrollArea import FXScrollArea

#: Extended selection mode allows for drag-selection of ranges of items.
LIST_EXTENDEDSELECT: int = hash("LIST_EXTENDEDSELECT")

#: Single selection mode allows up to one item to be selected.
LIST_SINGLESELECT: int = hash("LIST_SINGLESELECT")

#: Browse selection mode enforces one single item to be selected at all times.
LIST_BROWSESELECT: int = hash("LIST_BROWSESELECT")

#: Multiple selection mode is used for selection of individual items.
LIST_MULTIPLESELECT: int = hash("LIST_MULTIPLESELECT")

#: Automatically select under cursor.
LIST_AUTOSELECT: int = hash("LIST_AUTOSELECT")

#: Normal list style.
LIST_NORMAL: int = hash("LIST_NORMAL")


class FXList(FXScrollArea):
    """List Widget."""

    def __init__(
        self,
        p: FXComposite,
        nvis: int,
        tgt: FXObject | None = None,
        sel: int = 0,
        opts: int = LIST_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
    ):
        """Construct a list with nvis visible items; the list is initially empty.

        Parameters
        ----------
        p : FXComposite

        nvis : int

        tgt : FXObject | None

        sel : int

        opts : int

        x : int

        y : int

        w : int

        h : int
        """

    def appendItem(self, item: FXListItem, notify: bool = False):
        """Append a [possibly subclassed] item to the list.

        Parameters
        ----------
        item : FXListItem

        notify : bool
        """

    def canFocus(self):
        """List widget can receive focus.

        Reimplemented from FXWindow.
        """

    def clearItems(self, notify: bool = False):
        """Remove all items from list.

        Parameters
        ----------
        notify : bool
        """

    def create(self):
        """Create server-side resources.

        Reimplemented from FXComposite.
        """

    def deselectItem(self, index: int, notify: bool = False):
        """Deselect item.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def detach(self):
        """Detach server-side resources.

        Reimplemented from FXComposite.
        """

    def findItem(self, text: str, start: int = -1):
        """Search items for item by name, starting from start item; the flags argument controls the search
        direction, and case sensitivity.

        Parameters
        ----------
        text : str

        start : int
        """

    def getContentHeight(self):
        """Return content height.

        Reimplemented from FXScrollArea.
        """

    def getContentWidth(self):
        """Compute and return content width.

        Reimplemented from FXScrollArea.
        """

    def getCurrentItem(self):
        """Return current item, if any."""

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXScrollArea. Reimplemented in AFXList.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXScrollArea.
        """

    def getItemData(self, index: int):
        """Return item user-data pointer.

        Parameters
        ----------
        index : int
        """

    def getItemHeight(self, index: int):
        """Return item height.

        Parameters
        ----------
        index : int
        """

    def getItemIcon(self, index: int):
        """Return item icon, if any.

        Parameters
        ----------
        index : int
        """

    def getItemText(self, index: int):
        """Return item text.

        Parameters
        ----------
        index : int
        """

    def getItemWidth(self, index: int):
        """Return item width.

        Parameters
        ----------
        index : int
        """

    def getListStyle(self):
        """Return list style."""

    def getNumItems(self):
        """Return the number of items in the list."""

    def getNumVisible(self):
        """Return number of visible items."""

    def insertItem(self, index: int, item: FXListItem, notify: bool = False):
        """Insert a new [possibly subclassed] item at the give index.

        Parameters
        ----------
        index : int

        item : FXListItem

        notify : bool
        """

    def isItemSelected(self, index: int):
        """Return True if item is selected.

        Parameters
        ----------
        index : int
        """

    def isItemVisible(self, index: int):
        """Return True if item is visible.

        Parameters
        ----------
        index : int
        """

    def killSelection(self, notify: bool = False):
        """Deselect all items.

        Parameters
        ----------
        notify : bool
        """

    def makeItemVisible(self, index: int):
        """Scroll to bring item into view.

        Parameters
        ----------
        index : int
        """

    def recalc(self):
        """Recalculate layout.

        Reimplemented from FXWindow.
        """

    def removeItem(self, index: int, notify: bool = False):
        """Remove item from list.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def replaceItem(self, index: int, item: FXListItem, notify: bool = False):
        """Replace the item with a [possibly subclassed] item.

        Parameters
        ----------
        index : int

        item : FXListItem

        notify : bool
        """

    def retrieveItem(self, index: int):
        """Return the item at the given index.

        Parameters
        ----------
        index : int
        """

    def selectItem(self, index: int, notify: bool = False):
        """Select item.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def setCurrentItem(self, index: int, notify: bool = False):
        """Change current item.

        Parameters
        ----------
        index : int

        notify : bool
        """

    def setItemData(self, index: int, ptr: str):
        """Change item user-data pointer.

        Parameters
        ----------
        index : int

        ptr : str
        """

    def setItemIcon(self, index: int, icon: FXIcon):
        """Change item icon.

        Parameters
        ----------
        index : int

        icon : FXIcon
        """

    def setItemText(self, index: int, text: str):
        """Change item text.

        Parameters
        ----------
        index : int

        text : str
        """

    def setListStyle(self, style: int):
        """Change list style.

        Parameters
        ----------
        style : int
        """

    def setNumVisible(self, nvis: int):
        """Change the number of visible items.

        Parameters
        ----------
        nvis : int
        """



from __future__ import annotations

from .FXButton import FXButton
from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXObject import FXObject


class AFXFlyoutItem(FXButton):
    """This class contains a button that is placed in the popup menu of the flyout button."""

    def __init__(
        self,
        p: FXComposite,
        text: str,
        ic: FXIcon | None = None,
        tgt: FXObject | None = None,
        sel: int = 0,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = 0,
        pr: int = 0,
        pt: int = 0,
        pb: int = 0,
    ):
        """Constructor.

        Parameters
        ----------
        p : FXComposite
            Parent widget.
        text : str
            Label string.
        ic : FXIcon | None
            Icon.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        x : int
            X coordinate of origin.
        y : int
            Y c coordinate of origin.
        w : int
            Width of the widget.
        h : int
            Height of the widget.
        pl : int
            Left padding (margin).
        pr : int
            Right padding (margin).
        pt : int
            Top padding (margin).
        pb : int
            Bottom padding (margin).
        """

    def canFocus(self):
        """Returns True (because a flyout item can receive focus).

        Reimplemented from FXButton.
        """

    def hide(self):
        """Hides the flyout item.

        Reimplemented from FXWindow.
        """

    def setIcon(self, ic: FXIcon):
        """Sets the icon for the flyout item. Reimplemented from FXLabel.

        Parameters
        ----------
        ic : FXIcon
        """



from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .InteractionState import InteractionState


@abaqus_class_doc
class FilmConditionState(InteractionState):
    """The FilmConditionState object stores the propagating data for a FilmCondition object. One instance of
    this object is created internally by the FilmCondition object for each step. The instance is also deleted
    internally by the FilmCondition object. The FilmConditionState object has no constructor or methods. The
    FilmConditionState object is derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - SFILM
        - FILM
    """

    #: A SymbolicConstant specifying the propagation state of the **interactionProperty** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    interactionPropertyState: SymbolicConstant

    #: A Float specifying the sink temperature.
    sinkTemperature: float | None = None

    #: A SymbolicConstant specifying the propagation state of the **sinkTemperature** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    sinkTemperatureState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **sinkAmplitude** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    sinkAmplitudeState: SymbolicConstant

    #: A Float specifying the film coefficient.
    filmCoeff: float | None = None

    #: A SymbolicConstant specifying the propagation state of the **filmCoeff** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    filmCoeffState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **filmCoeffAmplitude** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    filmCoeffAmplitudeState: SymbolicConstant

    #: A String specifying the FilmConditionProp object associated with this interaction.
    interactionProperty: str = ""

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: sink temperature.
    sinkAmplitude: str = ""

    #: A String specifying the name of the Amplitude object that gives the variation of the
    #: film coefficient.
    filmCoeffAmplitude: str = ""

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant



from __future__ import annotations

from .FXComposite import FXComposite

#: Show the scrollbars when needed.
SCROLLERS_NORMAL: int = hash("SCROLLERS_NORMAL")

#: Always show horizontal scrollers.
HSCROLLER_ALWAYS: int = hash("HSCROLLER_ALWAYS")

#: Never show horizontal scrollers.
HSCROLLER_NEVER: int = hash("HSCROLLER_NEVER")

#: Always show vertical scrollers.
VSCROLLER_ALWAYS: int = hash("VSCROLLER_ALWAYS")

#: Never show vertical scrollers.
VSCROLLER_NEVER: int = hash("VSCROLLER_NEVER")

#: Horizontal scrolling turned on (default).
HSCROLLING_ON: int = hash("HSCROLLING_ON")

#: Horizontal scrolling turned off.
HSCROLLING_OFF: int = hash("HSCROLLING_OFF")

#: Vertical scrolling turned on (default).
VSCROLLING_ON: int = hash("VSCROLLING_ON")

#: Vertical scrolling turned off.
VSCROLLING_OFF: int = hash("VSCROLLING_OFF")

#: Scrollers track continuously for smooth scrolling.
SCROLLERS_TRACK: int = hash("SCROLLERS_TRACK")

#: Scrollers don't track continuously.
SCROLLERS_DONT_TRACK: int = hash("SCROLLERS_DONT_TRACK")


class FXScrollArea(FXComposite):
    """The scroll area widget manages a content area and a viewport area through which the content is viewed.

    When the content area becomes larger than the viewport area, scrollbars are placed to permit viewing of
    the entire content by scrolling the content. Depending on the mode, scrollbars may be displayed on an
    as-needed basis, always, or never. Normally, the scroll area's size and the content's size are
    independent; however, it is possible to disable scrolling in the horizontal (vertical) direction. In
    this case, the content width (height) will influence the width (height) of the scroll area widget. For
    content which is time-consuming to repaint, continuous scrolling may be turned off.
    """

    def getContentWidth(self):
        """Return content size.

        Reimplemented in FXIconList, FXImageView, FXList, FXMDIClient, FXScrollWindow, FXTable, FXText,
        FXTreeList, AFXBaseTable, and AFXOptionTreeList.
        """

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXComposite. Reimplemented in FXList, FXTable, FXText, FXTreeList, AFXBaseTable,
        AFXList, AFXOptionTreeList, AFXTable, and AFXTreeTable.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXComposite. Reimplemented in FXList, FXTable, FXText, FXTreeList, AFXBaseTable,
        AFXOptionTreeList, AFXTable, and AFXTreeTable.
        """

    def getPosition(self, x: int, y: int):
        """Get the current position.

        Parameters
        ----------
        x : int

        y : int
        """

    def getScrollStyle(self):
        """Return scroll style."""

    def getViewportHeight(self):
        """Return viewport size.

        Reimplemented in FXIconList.
        """

    def getXPosition(self):
        """Return the current x-position."""

    def getYPosition(self):
        """Return the current y-position."""

    def horizontalScrollbar(self):
        """Return a pointer to the horizontal scrollbar."""

    def isHorizontalScrollable(self):
        """Return True if horizontally scrollable."""

    def isVerticalScrollable(self):
        """Return True if vertically scrollable."""

    def moveContents(self, x: int, y: int):
        """Move contents to the specified position. Reimplemented in FXIconList, FXMDIClient, FXScrollWindow,
        FXTable, FXText, AFXBaseTable, AFXOptionTreeList, and AFXTable.

        Parameters
        ----------
        x : int

        y : int
        """

    def setPosition(self, x: int, y: int):
        """Set the current position.

        Parameters
        ----------
        x : int

        y : int
        """

    def setScrollStyle(self, style: int):
        """Change scroll style.

        Parameters
        ----------
        style : int
        """

    def verticalScrollbar(self):
        """Return a pointer to the vertical scrollbar."""
